@@ -29,27 +29,30 @@ from vdsm.storage import constants as sc
 from vdsm.storage import exception
 
 
-# SIZE property was deprecated in metadata v5, but we still need this key to
-# read and write legacy metadata. To make sure no other code use it and it's
-# used only by metadata code, move it here and make it private.
-_SIZE = "SIZE"
-
-
 class VolumeMetadata(object):
 
     log = logging.getLogger('storage.VolumeMetadata')
 
-    def __init__(self, domain, image, puuid, capacity, format, type, voltype,
+    def __init__(self, domain, image, puuid, size, format, type, voltype,
                  disktype, description="", legality=sc.ILLEGAL_VOL, ctime=None,
                  generation=sc.DEFAULT_GENERATION):
+        if not isinstance(size, six.integer_types):
+            raise AssertionError("Invalid value for 'size': {!r}".format(size))
+        if ctime is not None and not isinstance(ctime, int):
+            raise AssertionError(
+                "Invalid value for 'ctime': {!r}".format(ctime))
+        if not isinstance(generation, int):
+            raise AssertionError(
+                "Invalid value for 'generation': {!r}".format(generation))
+
         # Storage domain UUID
         self.domain = domain
         # Image UUID
         self.image = image
         # UUID of the parent volume or BLANK_UUID
         self.puuid = puuid
-        # Volume capacity in bytes
-        self.capacity = capacity
+        # Volume size in blocks
+        self.size = size
         # Format (RAW or COW)
         self.format = format
         # Allocation policy (PREALLOCATED or SPARSE)
@@ -79,18 +82,10 @@ class VolumeMetadata(object):
             md[key.strip()] = value.strip()
 
         try:
-            # We work internally in bytes, even if old format store
-            # value in blocks, we will read SIZE instead of CAPACITY
-            # from non-converted volumes and use it
-            if sc.CAPACITY in md:
-                capacity = int(md[sc.CAPACITY])
-            else:
-                capacity = int(md[_SIZE]) * sc.BLOCK_SIZE_512
-
             return cls(domain=md[sc.DOMAIN],
                        image=md[sc.IMAGE],
                        puuid=md[sc.PUUID],
-                       capacity=capacity,
+                       size=int(md[sc.SIZE]),
                        format=md[sc.FORMAT],
                        type=md[sc.TYPE],
                        voltype=md[sc.VOLTYPE],
@@ -106,14 +101,8 @@ class VolumeMetadata(object):
                        generation=int(md.get(sc.GENERATION,
                                              sc.DEFAULT_GENERATION)))
         except KeyError as e:
-            if "NONE" in md:
-                # Before 4.20.34-1 (ovirt 4.2.5) volume metadata could be
-                # cleared by writing invalid metadata when deleting a volume.
-                # See https://bugzilla.redhat.com/1574631.
-                raise exception.MetadataCleared("lines={}".format(lines))
-
             raise exception.MetaDataKeyNotFoundError(
-                "key={} lines={}".format(e, lines))
+                "Missing metadata key: %s: found: %s" % (e, md))
 
     @property
     def description(self):
@@ -123,38 +112,6 @@ class VolumeMetadata(object):
     def description(self, desc):
         self._description = self.validate_description(desc)
 
-    @property
-    def capacity(self):
-        return self._capacity
-
-    @capacity.setter
-    def capacity(self, value):
-        self._capacity = self._validate_integer("capacity", value)
-
-    @property
-    def ctime(self):
-        return self._ctime
-
-    @ctime.setter
-    def ctime(self, value):
-        self._ctime = self._validate_integer("ctime", value)
-
-    @property
-    def generation(self):
-        return self._generation
-
-    @generation.setter
-    def generation(self, value):
-        self._generation = self._validate_integer("generation", value)
-
-    @classmethod
-    def _validate_integer(cls, property, value):
-        if not isinstance(value, six.integer_types):
-            raise AssertionError(
-                "Invalid value for metadata property {!r}: {!r}".format(
-                    property, value))
-        return value
-
     @classmethod
     def validate_description(cls, desc):
         desc = str(desc)
@@ -167,35 +124,17 @@ class VolumeMetadata(object):
             desc = desc[:sc.DESCRIPTION_SIZE]
         return desc
 
-    def storage_format(self, domain_version, **overrides):
+    def storage_format(self, domain_version):
         """
         Format metadata string in storage format.
 
-        VolumeMetadata is quite restrictive and doesn't allows
-        you to make an invalid metadata, but sometimes, for example
-        for a format conversion, you need some additional fields to
-        be written to the storage. Those fields can be added using
-        overrides dict.
-
         Raises MetadataOverflowError if formatted metadata is too long.
 
         NOTE: Not used yet! We need to drop legacy_info() and pass
         VolumeMetadata instance instead of a dict to use this code.
         """
 
-        info = {
-            sc.CTIME: str(self.ctime),
-            sc.DESCRIPTION: self.description,
-            sc.DISKTYPE: self.disktype,
-            sc.DOMAIN: self.domain,
-            sc.FORMAT: self.format,
-            sc.GENERATION: self.generation,
-            sc.IMAGE: self.image,
-            sc.LEGALITY: self.legality,
-            sc.PUUID: self.puuid,
-            sc.TYPE: self.type,
-            sc.VOLTYPE: self.voltype,
-        }
+        info = dict(self.iteritems())
         if domain_version < 5:
             # Always zero on pre v5 domains
             # We need to keep MTIME available on pre v5
@@ -203,14 +142,6 @@ class VolumeMetadata(object):
             # field to exists and will fail without it.
             info[sc.MTIME] = 0
 
-            # Pre v5 domains should have SIZE in blocks
-            # instead of CAPACITY in bytes
-            info[_SIZE] = self.capacity // sc.BLOCK_SIZE_512
-        else:
-            info[sc.CAPACITY] = self.capacity
-
-        info.update(overrides)
-
         keys = sorted(info.keys())
         lines = ["%s=%s\n" % (key, info[key]) for key in keys]
         lines.append("EOF\n")
@@ -224,16 +155,12 @@ class VolumeMetadata(object):
     # with values, we return self and mimick dict behaviour.
     # In the fieldmap we keep mapping between metadata
     # field name and our internal field names
-    #
-    # TODO: All dict specific code below should be removed, when rest of VDSM
-    # will be refactored, to use VolumeMetadata properties, instead of dict
-
     _fieldmap = {
         sc.FORMAT: 'format',
         sc.TYPE: 'type',
         sc.VOLTYPE: 'voltype',
         sc.DISKTYPE: 'disktype',
-        sc.CAPACITY: 'capacity',
+        sc.SIZE: 'size',
         sc.CTIME: 'ctime',
         sc.DOMAIN: 'domain',
         sc.IMAGE: 'image',
@@ -250,7 +177,7 @@ class VolumeMetadata(object):
             raise KeyError(item)
 
         # Some fields needs to be converted to string
-        if item in (sc.CAPACITY, sc.CTIME):
+        if item in (sc.SIZE, sc.CTIME):
             value = str(value)
         return value
 
@@ -262,3 +189,7 @@ class VolumeMetadata(object):
             return self[item]
         except KeyError:
             return default
+
+    def iteritems(self):
+        for item in self._fieldmap:
+            yield (item, self[item])
