@@ -25,6 +25,7 @@ import uuid
 
 import pytest
 
+from vdsm.storage import blockSD
 from vdsm.storage import constants as sc
 from vdsm.storage import exception as se
 from vdsm.storage import clusterlock
@@ -39,8 +40,6 @@ from storage.storagetestlib import (
     make_file_volume,
 )
 
-from . marks import xfail_python3
-
 MB = 1048576
 
 # We want to create volumes larger than the minimum block volume size
@@ -48,12 +47,10 @@ MB = 1048576
 VOLSIZE = 256 * MB
 
 
-@xfail_python3
 class ManifestMixin(object):
 
     def test_init_failure_raises(self, monkeypatch):
-        def fail(sdUUID, idsPath, lease, alignment=sc.ALIGNMENT_1M,
-                 block_size=sc.BLOCK_SIZE_512):
+        def fail(*args):
             raise RuntimeError("injected failure")
 
         with self.env() as env:
@@ -62,7 +59,6 @@ class ManifestMixin(object):
                 env.sd_manifest.initDomainLock()
 
 
-@xfail_python3
 class TestFileManifest(ManifestMixin):
     env = fake_file_env
 
@@ -131,7 +127,6 @@ class TestFileManifest(ManifestMixin):
             env.sd_manifest.purgeImage(sd_id, img_id, [vol_id], False)
 
 
-@xfail_python3
 class TestBlockManifest(ManifestMixin):
     env = fake_block_env
 
@@ -161,11 +156,33 @@ class TestBlockManifest(ManifestMixin):
             assert (env.sd_manifest.sdUUID ==
                     env.sd_manifest.getMetaParam(sd.DMDK_SDUUID))
 
+    def test_getblocksize_defaults(self):
+        with self.env() as env:
+            assert 512 == env.sd_manifest.logBlkSize
+            assert 512 == env.sd_manifest.phyBlkSize
+
+    def test_overwrite_blocksize(self):
+        metadata = {sd.DMDK_VERSION: 3,
+                    blockSD.DMDK_LOGBLKSIZE: 2048,
+                    blockSD.DMDK_PHYBLKSIZE: 1024}
+        with self.env() as env:
+            # Replacing the metadata will not overwrite these values since they
+            # are set only in the manifest constructor.
+            env.sd_manifest.replaceMetadata(metadata)
+            assert 512 == env.sd_manifest.logBlkSize
+            assert 512 == env.sd_manifest.phyBlkSize
+
+            # If we supply values in the metadata used to construct the
+            # manifest then those values will apply.
+            new_manifest = blockSD.BlockStorageDomainManifest(
+                env.sd_manifest.sdUUID, metadata)
+            assert 2048 == new_manifest.logBlkSize
+            assert 1024 == new_manifest.phyBlkSize
+
 
-@xfail_python3
 class TestBlockDomainMetadataSlot:
 
-    # Note: the first 4 slots (0-3) are reserved for domain metadata in V3,4
+    # Note: the first 4 slots (0-3) are reserved for domain metadata
     @pytest.mark.parametrize("used_slots, free_slot", [
         [[], 4],
         [[4], 5],
@@ -173,22 +190,8 @@ class TestBlockDomainMetadataSlot:
         [[4, 6], 5],
         [[4, 7], 5],
     ])
-    @pytest.mark.parametrize("sd_version", [3, 4])
-    def test_metaslot_selection_v4(self, used_slots, free_slot, sd_version):
-        self._metaslot_selection(used_slots, free_slot, sd_version)
-
-    @pytest.mark.parametrize("used_slots, free_slot", [
-        [[], 1],
-        [[1], 2],
-        [[2], 1],
-        [[1, 3], 2],
-        [[1, 4], 2],
-    ])
-    def test_metaslot_selection_v5(self, used_slots, free_slot):
-        self._metaslot_selection(used_slots, free_slot, 5)
-
-    def _metaslot_selection(self, used_slots, free_slot, sd_version):
-        with fake_block_env(sd_version=sd_version) as env:
+    def test_metaslot_selection(self, used_slots, free_slot):
+        with fake_block_env() as env:
             for offset in used_slots:
                 lv = make_uuid()
                 sduuid = env.sd_manifest.sdUUID
@@ -198,9 +201,8 @@ class TestBlockDomainMetadataSlot:
             with env.sd_manifest.acquireVolumeMetadataSlot(None) as mdSlot:
                 assert mdSlot == free_slot
 
-    @pytest.mark.parametrize("sd_version", [3, 4, 5])
-    def test_metaslot_lock(self, sd_version):
-        with fake_block_env(sd_version=sd_version) as env:
+    def test_metaslot_lock(self):
+        with fake_block_env() as env:
             with env.sd_manifest.acquireVolumeMetadataSlot(None):
                 acquired = env.sd_manifest._lvTagMetaSlotLock.acquire(False)
                 assert not acquired
